pub struct Node {
pub bucket: u32,
pub next: u32,
pub value: Pubkey,
}Fields
bucket: u32next: u32value: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for Node
impl BorshDeserialize for Node
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Node
impl BorshSerialize for Node
impl Eq for Node
impl StructuralPartialEq for Node